@@ -1,5 +1,7 @@
 import requests
 import json
+from serpapi.pagination import Pagination
+from serpapi.serp_api_client_exception import SerpApiClientException
 
 GOOGLE_ENGINE = 'google'
 BING_ENGINE = 'bing'
@@ -8,18 +10,20 @@ GOOGLE_SCHOLAR_ENGINE = 'google_scholar'
 YANDEX_ENGINE = 'yandex'
 EBAY_ENGINE = 'ebay'
 YAHOO_ENGINE = 'yahoo'
+HOME_DEPOT_ENGINE = 'home_depot'
+YOUTUBE_ENGINE = 'youtube'
 
 class SerpApiClient(object):
-    """SerpApiClient enables to search any engine support by SerpApi and parse the result.
+    """SerpApiClient enables to query any search engines supported by SerpApi and parse the results.
     ```python
-    from serpapi import GoogleSearchResults
-    client = SerpApiClient({
+    from serpapi import GoogleSearch
+    search = SerpApiClient({
         "q": "Coffee", 
         "location": "Austin,Texas", 
         "engine": "google",
         "api_key": "<your private key>"
         })
-	data = client.get_json()
+	data = search.get_json()
     ```
 
     https://serpapi.com/search-api
@@ -28,9 +32,10 @@ class SerpApiClient(object):
     BACKEND = "https://serpapi.com"
     SERP_API_KEY = None
 
-    def __init__(self, params_dict, engine = None):
+    def __init__(self, params_dict, engine = None, timeout = 60000):
         self.params_dict = params_dict
         self.engine = engine
+        self.timeout = timeout
 
     def construct_url(self, path = "/search"):
         self.params_dict['source'] = 'python'
@@ -40,21 +45,30 @@ class SerpApiClient(object):
             if not 'engine' in self.params_dict:
                 self.params_dict['engine'] = self.engine
         if not 'engine' in self.params_dict:
-            raise "engine must be defined in params_dict or engine"
-
+            raise SerpApiClientException("engine must be defined in params_dict or engine")
         return self.BACKEND + path, self.params_dict
 
-    def get_results(self, path = '/search'):
+    def get_response(self, path = '/search'):
+        """Returns:
+            Response object provided by requests.get
+        """
         url = None
         try:
             url, parameter = self.construct_url(path)
-            response = requests.get(url, parameter, timeout=60000)
-            return response.text
+            print(url)
+            response = requests.get(url, parameter, timeout=self.timeout)
+            return response
         except requests.HTTPError as e:
             print("fail: " + url)
             print(e, e.response.status_code)
             raise e
 
+    def get_results(self, path='/search'):
+        """Returns:
+            Response text field
+        """
+        return self.get_response(path).text
+
     def get_html(self):
         """Returns:
             Raw HTML search result from Gooogle
@@ -63,11 +77,18 @@ class SerpApiClient(object):
 
     def get_json(self):
         """Returns:
-            Formatted search result as JSON
+            Formatted JSON search results using json package
         """
         self.params_dict["output"] = "json"
         return json.loads(self.get_results())
 
+    def get_raw_json(self):
+        """Returns:
+            Formatted JSON search result as string
+        """
+        self.params_dict["output"] = "json"
+        return self.get_results()
+
     def get_dictionary(self):
         """Returns:
             Dict with the formatted response content
@@ -81,6 +102,39 @@ class SerpApiClient(object):
         """
         return self.get_dictionary()
 
+    def get_object(self):
+        """Returns: 
+            Dynamically created python object wrapping the result data structure
+        """
+        # iterative over response hash
+        node = self.get_dictionary()
+        # create dynamic python object
+        return self.make_pyobj("response", node)
+
+    def make_pyobj(self, name, node):
+        pytype = type(name, (object, ), {})
+        pyobj = pytype()
+
+        if isinstance(node, list):
+            setattr(pyobj, name, [])
+            for el in node:
+                getattr(pyobj, name).append(self.make_pyobj(name, el))
+            return pyobj
+        elif isinstance(node, dict):
+            for name, child in node.items():
+                if isinstance(child, list):
+                    setattr(pyobj, name, [])
+                    for el in child:
+                        getattr(pyobj, name).append(self.make_pyobj(name, el))
+                elif isinstance(child, dict):
+                    setattr(pyobj, name, self.make_pyobj(name, child))
+                else:
+                    setattr(pyobj, name, child)
+        else:
+            setattr(pyobj, name, node)
+
+        return pyobj
+
     def get_search_archive(self, search_id, format = 'json'):
         """Retrieve search result from the Search Archive API
         Parameters:
@@ -107,11 +161,17 @@ class SerpApiClient(object):
             q (string): location (like: city name..)
             limit (int): number of matches returned
         Returns:
-            Dict: Location matching q
+            dict: Location matching q
         """
         self.params_dict = {}
         self.params_dict["output"] = "json"
         self.params_dict["q"] = q
         self.params_dict["limit"] = limit
-        return json.loads(self.get_results('/locations.json'))
-
+        buffer = self.get_results('/locations.json')
+        return json.loads(buffer)
+    
+    def pagination(self, start = 0, end = 1000000000, page_size = 10):
+        """Return:
+            Generator to iterate the search results pagination
+        """
+        return Pagination(self, start, end, page_size)
