@@ -17,8 +17,8 @@ else:
 # Time utility
 import time
 
-# Serp API client
-from serpapi import GoogleSearchResults
+# Serp API search
+from serpapi import GoogleSearch
 
 # download file with wget
 #import wget
@@ -26,12 +26,25 @@ from serpapi import GoogleSearchResults
 class TestExample(unittest.TestCase):
 
     def setUp(self):
-        GoogleSearchResults.SERP_API_KEY = os.getenv("API_KEY","demo")
+        GoogleSearch.SERP_API_KEY = os.getenv("API_KEY","demo")
 
     @unittest.skipIf((os.getenv("API_KEY") == None), "no api_key provided")
+    def test_get_json(self):
+        search = GoogleSearch({"q": "Coffee", "engine": "google_scholar"})
+        data = search.get_json()
+        print(data['search_metadata'])
+        search_id = data['search_metadata']['id']
+        # retrieve search from the archive - blocker
+        print(search_id + ": get search from archive")
+        raw_html =  search.get_search_archive(search_id, 'html')
+        # print(search_id + ": status = " + search_archived['search_metadata']['status'])
+        print(raw_html)
+        #print(search_html)
+
+    @unittest.skipIf((os.getenv("DEBUGAPI_KEY") == None), "no api_key provided")
     def test_search_google_images(self):
-        client = GoogleSearchResults({"q": "coffe", "tbm": "isch"})
-        for image_result in client.get_json()['images_results']:
+        search = GoogleSearch({"q": "coffe", "tbm": "isch"})
+        for image_result in search.get_json()['images_results']:
             try:
                 link = image_result["original"]
                 print("link is found: " + link)
@@ -42,13 +55,13 @@ class TestExample(unittest.TestCase):
                 pass
             # https://github.com/serpapi/showcase-serpapi-tensorflow-keras-image-training/blob/master/fetch.py
 
-    @unittest.skipIf((os.getenv("API_KEY") == None), "no api_key provided")
+    @unittest.skipIf((os.getenv("DEBUGAPI_KEY") == None), "no api_key provided")
     def test_async(self):
         # store searches
         search_queue = Queue()
         
-        # Serp API client
-        client = GoogleSearchResults({
+        # Serp API search
+        search = GoogleSearch({
             "location": "Austin,Texas",
             "async": True
         })
@@ -56,23 +69,26 @@ class TestExample(unittest.TestCase):
         # loop through companies
         for company in ['amd','nvidia','intel']:
           print("execute async search: q = " + company)
-          client.params_dict["q"] = company
-          search = client.get_dict()
-          print("add search to the queue where id: " + search['search_metadata']['id'])
+          search.params_dict["q"] = company
+          data = search.get_dict()
+          if data is not None:
+              print("oops data is empty for: " + company)
+              continue
+          print("add search to the queue where id: " + data['search_metadata']['id'])
           # add search to the search_queue
-          search_queue.put(search)
+          search_queue.put(data)
         
         print("wait until all search statuses are cached or success")
         
-        # Create regular client
-        client = GoogleSearchResults({"async": True})
+        # Create regular search
+        search = GoogleSearch({"async": True})
         while not search_queue.empty():
-          search = search_queue.get()
-          search_id = search['search_metadata']['id']
+          data = search_queue.get()
+          search_id = data['search_metadata']['id']
 
           # retrieve search from the archive - blocker
           print(search_id + ": get search from archive")
-          search_archived =  client.get_search_archive(search_id)
+          search_archived =  search.get_search_archive(search_id)
           print(search_id + ": status = " + search_archived['search_metadata']['status'])
           
           # check status
@@ -82,51 +98,52 @@ class TestExample(unittest.TestCase):
             # requeue search_queue
             print(search_id + ": requeue search")
             search_queue.put(search)
-            
             # wait 1s
             time.sleep(1)
-            
+        # search is over.
         print('all searches completed')
         
-        
-
-    @unittest.skipIf((os.getenv("API_KEY") == None), "no api_key provided")
+    @unittest.skipIf((os.getenv("DEBUGAPI_KEY") == None), "no api_key provided")
     def test_search_google_news(self):
-        client = GoogleSearchResults({
-            "q": "coffe",   # search client
-            "tbm": "nws",  # news
+        search = GoogleSearch({
+            "q": "coffe",   # search search
+            "tbm": "nws",   # news
             "tbs": "qdr:d", # last 24h
             "num": 10
         })
         for offset in [0,1,2]:
-            client.params_dict["start"] = offset * 10
-            data = client.get_json()
+            search.params_dict["start"] = offset * 10
+            data = search.get_json()
             for news_result in data['news_results']:
                 print(str(news_result['position'] + offset * 10) + " - " + news_result['title'])
 
-    @unittest.skipIf((os.getenv("API_KEY") == None), "no api_key provided")
+    @unittest.skipIf((os.getenv("DEBUGAPI_KEY") == None), "no api_key provided")
     def test_search_google_shopping(self):
-        client = GoogleSearchResults({
-            "q": "coffe",   # search client
+        search = GoogleSearch({
+            "q": "coffe",   # search search
             "tbm": "shop",  # news
             "tbs": "p_ord:rv", # last 24h
             "num": 100
         })
-        data = client.get_json()
-        for shopping_result in data['shopping_results']:
-            print(str(shopping_result['position']) + " - " + shopping_result['title'])
-
-    @unittest.skipIf((os.getenv("API_KEY") == None), "no api_key provided")
+        data = search.get_json()
+        if 'shopping_results' in data:
+            for shopping_result in data['shopping_results']:
+                print(str(shopping_result['position']) + " - " + shopping_result['title'])
+        else:
+            print("WARNING: oops shopping_results is missing from search result with tbm=shop")
+    
+    @unittest.skipIf((os.getenv("DEBUGAPI_KEY") == None), "no api_key provided")
     def test_search_by_location(self):
         for city in ["new york", "paris", "berlin"]:
-            location = GoogleSearchResults({}).get_location(city, 1)[0]["canonical_name"]
-            client = GoogleSearchResults({
-                "q": "best coffee shop",   # search client
+            location = GoogleSearch({}).get_location(city, 1)[0]["canonical_name"]
+            search = GoogleSearch({
+                "q": "best coffee shop",   # search search
                 "location": location,
                 "num": 10,
                 "start": 0
             })
-            data = client.get_json()
+            data = search.get_json()
+            self.assertIsNone(data.get("error"))
             top_result = data['organic_results'][0]["title"]
             print("top coffee result for " + location + " is: " + top_result)
 
