@@ -2,17 +2,18 @@ import random
 import unittest
 import os
 import pprint
-from serpapi import GoogleScholarSearchResults
+from serpapi import GoogleScholarSearch
    
-class TestGoogleScholarSearchResults(unittest.TestCase):
+class TestGoogleScholarSearch(unittest.TestCase):
 
 		def setUp(self):
-				GoogleScholarSearchResults.SERP_API_KEY = os.getenv("API_KEY", "demo")
+				GoogleScholarSearch.SERP_API_KEY = os.getenv("API_KEY", "demo")
 
 		@unittest.skipIf((os.getenv("API_KEY") == None), "no api_key provided")
 		def test_get_json(self):
-				client = GoogleScholarSearchResults({"q": "Coffee"})
-				data = client.get_json()
+				search = GoogleScholarSearch({"q": "Coffee"})
+				data = search.get_json()
+				self.assertIsNone(data.get("error"))
 				self.assertEqual(data["search_metadata"]["status"], "Success")
 				self.assertIsNotNone(data["search_metadata"]["id"])
 				self.assertIsNotNone(data["organic_results"][0]["title"])
