@@ -2,19 +2,19 @@ import random
 import unittest
 import pprint
 import os
-from serpapi import GoogleSearchResults
+from serpapi import GoogleSearch
 
 class TestLocationApi(unittest.TestCase):
 
     def setUp(self):
-        GoogleSearchResults.SERP_API_KEY = os.getenv("API_KEY","demo")
+        GoogleSearch.SERP_API_KEY = os.getenv("API_KEY","demo")
 
     def test_get_location(self):
-        client = GoogleSearchResults({"q": None, "async": True})
-        location_list = client.get_location("Austin", 3)
-        self.assertIsNotNone(location_list[0].get("id"))
+        search = GoogleSearch({"q": None, "async": True})
+        location_list = search.get_location("Austin", 3)
         pp = pprint.PrettyPrinter(indent=2)
         pp.pprint(location_list)
+        self.assertIsNotNone(location_list[0].get("id"))
 
 if __name__ == '__main__':
     unittest.main()
